@@ -26,14 +26,14 @@ import java.util.List;
         exitCodeOnInvalidInput = SOPGPException.UnsupportedOption.EXIT_CODE)
 public class DecryptCmd extends AbstractSopCmd {
 
+    private static final String OPT_SESSION_KEY_OUT = "--session-key-out";
     private static final String OPT_WITH_SESSION_KEY = "--with-session-key";
     private static final String OPT_WITH_PASSWORD = "--with-password";
-    private static final String OPT_NOT_BEFORE = "--not-before";
-    private static final String OPT_NOT_AFTER = "--not-after";
-    private static final String OPT_SESSION_KEY_OUT = "--session-key-out";
-    private static final String OPT_VERIFICATIONS_OUT = "--verifications-out";
-    private static final String OPT_VERIFY_WITH = "--verify-with";
     private static final String OPT_WITH_KEY_PASSWORD = "--with-key-password";
+    private static final String OPT_VERIFICATIONS_OUT = "--verifications-out"; // see SOP-05
+    private static final String OPT_VERIFY_WITH = "--verify-with";
+    private static final String OPT_NOT_BEFORE = "--verify-not-before";
+    private static final String OPT_NOT_AFTER = "--verify-not-after";
 
 
     @CommandLine.Option(
@@ -101,6 +101,7 @@ public class DecryptCmd extends AbstractSopCmd {
             DecryptionResult result = ready.writeTo(System.out);
             writeSessionKeyOut(result);
             writeVerifyOut(result);
+
         } catch (SOPGPException.BadData badData) {
             String errorMsg = getMsg("sop.error.input.stdin_not_a_message");
             throw new SOPGPException.BadData(errorMsg, badData);
@@ -114,6 +115,11 @@ public class DecryptCmd extends AbstractSopCmd {
 
     private void writeVerifyOut(DecryptionResult result) throws IOException {
         if (verifyOut != null) {
+            if (result.getVerifications().isEmpty()) {
+                String errorMsg = getMsg("sop.error.runtime.no_verifiable_signature_found");
+                throw new SOPGPException.NoSignature(errorMsg);
+            }
+
             try (OutputStream fileOut = getOutput(verifyOut)) {
                 PrintWriter writer = new PrintWriter(fileOut);
                 for (Verification verification : result.getVerifications()) {
