@@ -32,7 +32,11 @@ public abstract class SOPGPException extends RuntimeException {
         public static final int EXIT_CODE = 3;
 
         public NoSignature() {
-            super("No verifiable signature found.");
+            this("No verifiable signature found.");
+        }
+
+        public NoSignature(String message) {
+            super(message);
         }
 
         public NoSignature(String errorMsg, NoSignature e) {
@@ -72,6 +76,10 @@ public abstract class SOPGPException extends RuntimeException {
             super(message, cause);
         }
 
+        public CertCannotEncrypt(String message) {
+            super(message);
+        }
+
         @Override
         public int getExitCode() {
             return EXIT_CODE;
@@ -85,8 +93,12 @@ public abstract class SOPGPException extends RuntimeException {
 
         public static final int EXIT_CODE = 19;
 
-        public MissingArg(String s) {
-            super(s);
+        public MissingArg() {
+
+        }
+
+        public MissingArg(String message) {
+            super(message);
         }
 
         @Override
@@ -127,6 +139,10 @@ public abstract class SOPGPException extends RuntimeException {
             super(errorMsg, e);
         }
 
+        public CannotDecrypt(String message) {
+            super(message);
+        }
+
         @Override
         public int getExitCode() {
             return EXIT_CODE;
@@ -144,6 +160,10 @@ public abstract class SOPGPException extends RuntimeException {
             super();
         }
 
+        public PasswordNotHumanReadable(String message) {
+            super(message);
+        }
+
         @Override
         public int getExitCode() {
             return EXIT_CODE;
@@ -203,6 +223,14 @@ public abstract class SOPGPException extends RuntimeException {
 
         public static final int EXIT_CODE = 53;
 
+        public ExpectedText() {
+            super();
+        }
+
+        public ExpectedText(String message) {
+            super(message);
+        }
+
         @Override
         public int getExitCode() {
             return EXIT_CODE;
